@@ -72,7 +72,10 @@ def get_sreg_settings():
 def build_return_to_url(request, return_view, redirect_field_name,
                         redirect_to):
     if hasattr(settings, 'OPENID_CUSTOM_RETURN_TO'):
-        return_to = getattr(settings, 'OPENID_CUSTOM_RETURN_TO') + reverse(return_view)
+        return_to = (
+                getattr(settings, 'OPENID_CUSTOM_RETURN_TO').rstrip("/")
+                + reverse(return_view)
+        )
     else:
         return_to = request.build_absolute_uri(reverse(return_view))
 
@@ -209,8 +212,10 @@ def render_openid_request(request, openid_request, return_to, immediate=False,
 def parse_openid_response(request):
     """Parse an OpenID response from a Django request."""
     if hasattr(settings, 'OPENID_CUSTOM_REALM'):
-        current_url = urljoin(getattr(settings, 'OPENID_CUSTOM_REALM'),
-                              request.get_full_path())
+        current_url = (
+                getattr(settings, 'OPENID_CUSTOM_REALM').rstrip("/") +
+                request.get_full_path()
+        )
     else:
         current_url = request.build_absolute_uri()
     consumer = make_consumer(request)
